@@ -3,6 +3,7 @@ var searchData=
   ['gain_5ffcns_5ft_0',['gain_fcns_t',['../structuhd_1_1gain__fcns__t.html',1,'uhd']]],
   ['gain_5fgroup_1',['gain_group',['../classuhd_1_1gain__group.html',1,'uhd']]],
   ['gpio_5fpower_5fiface_2',['gpio_power_iface',['../classuhd_1_1features_1_1gpio__power__iface.html',1,'uhd::features']]],
-  ['gps_5fctrl_3',['gps_ctrl',['../classuhd_1_1gps__ctrl.html',1,'uhd']]],
-  ['graph_5fedge_5ft_4',['graph_edge_t',['../structuhd_1_1rfnoc_1_1graph__edge__t.html',1,'uhd::rfnoc']]]
+  ['gps_5fiface_3',['gps_iface',['../classuhd_1_1features_1_1gps__iface.html',1,'uhd::features']]],
+  ['graph_5fedge_5ft_4',['graph_edge_t',['../structuhd_1_1rfnoc_1_1graph__edge__t.html',1,'uhd::rfnoc']]],
+  ['graph_5ft_5',['graph_t',['../classuhd_1_1rfnoc_1_1detail_1_1graph__t.html',1,'uhd::rfnoc::detail']]]
 ];
